wolfrpg_map_parser::command

Enum Command

pub enum Command {
Show 23 variants ShowMessage(ShowTextCommand), Comment(ShowTextCommand), DebugText(ShowTextCommand), ForceCloseMessage(), ClearDebugText(), ShowChoice(ShowChoiceCommand), SetVariable(SetVariableCommand), DBManagement(DBManagementCommand), SetString(SetStringCommand), SetVariablePlus(SetVariablePlusCommand), NumberCondition(NumberConditionCommand), StringCondition(StringConditionCommand), InputKey(InputKeyCommand), Picture(PictureCommand), Effect(EffectCommand), Sound(SoundCommand), SaveLoad(SaveLoadCommand), PartyGraphics(PartyGraphicsCommand), ChipManagement(ChipManagementCommand), Transfer(TransferCommand), EventControl(EventControlCommand), CommonEvent(CommonEventCommand), Exit(),
}
An event command instruction.

A command can be anything from a single instruction to a loop containing other instructions. Because of the inherently-recursive nature of this enum, it is probably best to create new traits and implement them for each variant.

Variants



ShowMessage(ShowTextCommand)



Comment(ShowTextCommand)



DebugText(ShowTextCommand)



ForceCloseMessage()



ClearDebugText()



ShowChoice(ShowChoiceCommand)



SetVariable(SetVariableCommand)



DBManagement(DBManagementCommand)



SetString(SetStringCommand)



SetVariablePlus(SetVariablePlusCommand)



NumberCondition(NumberConditionCommand)



StringCondition(StringConditionCommand)



InputKey(InputKeyCommand)



Picture(PictureCommand)



Effect(EffectCommand)



Sound(SoundCommand)



SaveLoad(SaveLoadCommand)



PartyGraphics(PartyGraphicsCommand)



ChipManagement(ChipManagementCommand)



Transfer(TransferCommand)



EventControl(EventControlCommand)



CommonEvent(CommonEventCommand)



Exit()

Implementations

Source

impl Command

pub fn parse(bytes: &[u8]) -> (usize, u32, Self)

Parse raw bytes into a single Command struct.

Use of this method is highly discouraged unless you know exactly what you are doing. Prefer using Map::parse and then extract what you want from the structure tree.

Panics

This function will panic if the given bytes do not represent a valid command structure.

This might be caused by unaligned bytes, corrupt files, incompatible format updates and library bugs. If you are confident you are doing everything right, feel free to report an issue on GitHub.

pub fn parse_multiple(bytes: &[u8]) -> (usize, u32, Vec<Command>)

Parse raw bytes into a Command collection.

Use of this method is highly discouraged unless you know exactly what you are doing. Prefer using Map::parse and then extract what you want from the structure tree.

Panics

This function will panic if the given bytes do not represent a valid command structure.

This might be caused by unaligned bytes, corrupt files, incompatible format updates and library bugs. If you are confident you are doing everything right, feel free to report an issue on GitHub.